from distutils.core import setup
#from setuptools import setup


setup(
    name = 'nester-another',
    version = '1.3.0',
    py_modules = ['nester-another'],
    author =    'Leoncio',
    author_email= 'leonciocast@gmail.com',
    url    =  'http://www.headfirstlabs.com'
    
    
)
